
pro rd_mdi, files, index, data, _extra=_extra
;+
;   Name: rd_mdi
;
;   Purpose: simple mdi front end to mreadfits; ssw-rationalize output
;
;   Input Parameters:
;      files - list of one or more mdi fits files
;
;   Output Paramters:
;      index - the structure equivilent header vector
;      data  - optional output 2D or 3D data
;
;   
;   Calling Sequence:
;     rd_mdi, filelist, index [,data ] [,outsize=outsize] [,/noscale]
;
;   History:
;      7-April-1998 - S.L.Freeland - handle the large SOI versions
;      24-April-1998 - Zarro, - added check for vector index
;       7-Nov-1998 - S.L.Freeland - pass NODATA->mreadfits based on n_param
;      12-nov-1998 - S.L.Freeland - added call to struct2ssw prior to exit
;      24-Nov-1999 - S.L.Freeland - pass unrecognized keywords->mreadfits
;                                   via inheritance.
;       5-Apr-2000 - S.L.Freeland - rationalize when No DATE_OBS, only TAI
;-     
mreadfits, files, index,data,strtemp=mdi_struct(), nodata=(n_params() le 2),$
   _extra=_extra

if gt_tagval(index(0),/crpix1) eq 0  and  gt_tagval(index(0),/center_x) ne 0 then begin
; convert some SOI fields -> SSW standards
  index.cdelt1=gt_tagval(index,/xscale)
  index.cdelt2=gt_tagval(index,/yscale)
  index.crpix1=gt_tagval(index,/center_x)
  index.crpix2=gt_tagval(index,/center_y)
  index.solar_r=gt_tagval(index,/r_sun)
endif

;  these work for all styles of MDI that I know about
t_obs=gt_tagval(index(0),/t_obs,missing='')

case 1 of
   strlen(index(0).date_obs) ge 18: ints=anytim(gt_tagval(index,/date_obs),/ints)
   strlen(index(0).date_obs) gt 1:  ints=anytim(index.date_obs + ' ' + index.time_obs,/ints) 
   t_obs ne '': ints=anytim(str2utc(index.t_obs),/ints)
   else: message,/con,'Unexpected MDI time format...'
endcase

index.time=ints.time
index.day=ints.day

index=struct2ssw(index)                        ; rationalize some time/point
; -------------------------------------------

return
end
